aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--perllib/FixMyStreet/SendReport/Open311.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perllib/FixMyStreet/SendReport/Open311.pm b/perllib/FixMyStreet/SendReport/Open311.pm
index d65a8ddb1..cfcac9bd8 100644
--- a/perllib/FixMyStreet/SendReport/Open311.pm
+++ b/perllib/FixMyStreet/SendReport/Open311.pm
@@ -127,8 +127,8 @@ sub send {
$revert = 1;
}
- if ($row->cobrand eq 'fixmybarangay') {
- # FixMyBarangay endpoints expect external_id as an attribute, as do Oxfordshire
+ if ($row->cobrand eq 'fixmybarangay' || $row->cobrand eq 'greenwich') {
+ # FixMyBarangay endpoints expect external_id as an attribute, as do Greenwich
$row->set_extra_fields( { 'name' => 'external_id', 'value' => $row->id } );
$revert = 1;
}